@@ -7,7 +7,7 @@ use base 'CGI::Application::Demo::Dispatch::Base';
 use strict;
 use warnings;
 
-our $VERSION = '1.03';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
@@ -16,23 +16,24 @@ sub cgiapp_init
 	my($self) = @_;
 
 	$self -> SUPER::cgiapp_init();
-	$self -> run_modes(['initialize']);
+	$self -> run_modes(['display']);
 
 } # End of cgiapp_init.
 
 # -----------------------------------------------
 
-sub initialize
+sub display
 {
 	my($self) = @_;
 	my($url)  = $self -> url();
+	$url      =~ s|/Person$||;
 
 	my(@row);
 
 	push @row, {th => 'Package',  td => __PACKAGE__};
 	push @row, {th => 'Run mode', td => $self -> get_current_runmode()};
 	push @row, {th => 'URL',      td => $self -> path_info()};
- 	push @row, {th => 'Go to',    td => "<a href='$url'>Menu</a>"};
+ 	push @row, {th => 'Go to',    td => "<a href='$url/Menu'>Menu</a>"};
  	push @row, {th => 'Go to',    td => "<a href='$url/Organization'>Organization</a>"};
 
 	my($table) = $self -> load_tmpl('table.tmpl');
@@ -45,7 +46,7 @@ sub initialize
 
 	return $page -> output();
 
-} # End of initialize.
+} # End of display.
 
 # -----------------------------------------------
 
